@@ -5,10 +5,10 @@
 
 /* .Call calls */
 void R_init_rrapply(DllInfo *dll);
-extern SEXP do_rrapply(SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP);
+extern SEXP C_rrapply(SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP);
 
 static const R_CallMethodDef CallEntries[] = {
-    {"do_rrapply", (DL_FUNC)&do_rrapply, 11},
+    {"C_rrapply", (DL_FUNC)&C_rrapply, 11},
     {NULL, NULL, 0}};
 
 void R_init_rrapply(DllInfo *dll)
